<?xml version="1.0" encoding="UTF-8"?>

<!--
 ********************************************************************
 * IBM Rational Developer for System z
 * IBM z/OS Automated Unit Testing Framework (zUnit)
 * AZU20T10
 *
 * This XSL stylesheet can be used to convert a version 2.0.x.x
 * zUnit test runner result file (*.azures) to a version 1.0.x.x
 * zUnit test runner result file (*.azures).
 *
 * @since   9.0.0.0
 * @version 9.0.0.0
 ********************************************************************
-->

<xsl:stylesheet
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:xalan="http://xml.apache.org/xslt"
    xmlns:v20="http://www.ibm.com/zUnit/2.0.0.0/TestRunner"
    xmlns:v10="http://www.ibm.com/zUnit/1.0.0.0/TestRunner"
    version="1.0">

    <xsl:output method="xml" encoding="UTF-8" indent="yes"
                standalone="yes" xalan:indent-amount="4"/>

    <xsl:template match="/">
        <xsl:apply-templates select="v20:RunnerResult"/>
    </xsl:template>

    <xsl:template match="v20:RunnerResult">
        <v10:RunnerResult>
            <xsl:attribute name="errorCount">
                <xsl:value-of select="@errors"/>
            </xsl:attribute>
            <xsl:attribute name="failCount">
                <xsl:value-of select="@failures"/>
            </xsl:attribute>
            <xsl:attribute name="passCount">
                <xsl:value-of select="@passed"/>
            </xsl:attribute>
            <xsl:attribute name="testCount">
                <xsl:value-of select="@tests"/>
            </xsl:attribute>
            <xsl:apply-templates select="v20:options"/>
            <xsl:apply-templates select="v20:testCase"/>
        </v10:RunnerResult>
    </xsl:template>

    <xsl:template match="v20:options">
        <v10:options>
            <xsl:if test="@contOnTestCaseError">
                <xsl:attribute name="contOnTestCaseError">
                    <xsl:value-of select="@contOnTestCaseError"/>
                </xsl:attribute>
            </xsl:if>
            <xsl:if test="@contOnTestCaseFail">
                <xsl:attribute name="contOnTestCaseFail">
                    <xsl:value-of select="@contOnTestCaseFail"/>
                </xsl:attribute>
            </xsl:if>
            <xsl:if test="@contOnTestError">
                <xsl:attribute name="contOnTestError">
                    <xsl:value-of select="@contOnTestError"/>
                </xsl:attribute>
            </xsl:if>
            <xsl:if test="@contOnTestFail">
                <xsl:attribute name="contOnTestFail">
                    <xsl:value-of select="@contOnTestFail"/>
                </xsl:attribute>
            </xsl:if>
        </v10:options>
    </xsl:template>

    <xsl:template match="v20:testCase">
        <v10:testCase>
            <xsl:attribute name="moduleName">
                <xsl:value-of select="@moduleName"/>
            </xsl:attribute>
            <v10:UUID>
                <xsl:value-of select="@id"/>
            </v10:UUID>
            <v10:name>
                <xsl:value-of select="@name"/>
            </v10:name>
            <v10:start>
                <xsl:value-of select="@startTimestamp"/>
            </v10:start>
            <xsl:if test="@tests">
                <v10:testCount>
                    <xsl:value-of select="@tests"/>
                </v10:testCount>
            </xsl:if>
            <xsl:apply-templates select="v20:test"/>
            <v10:end>
                <xsl:value-of select="@endTimestamp"/>
            </v10:end>
            <v10:result>
                <xsl:value-of select="@result"/>
            </v10:result>
            <xsl:if test="v20:failure">
                <v10:exception>
                    <xsl:if test="v20:failure/@componentCode">
                        <v10:componentCode>
                            <xsl:value-of select="v20:failure/@componentCode"/>
                        </v10:componentCode>
                    </xsl:if>
                    <xsl:if test="v20:failure/@messageNumber">
                        <v10:messageNumber>
                            <xsl:value-of select="v20:failure/@messageNumber"/>
                        </v10:messageNumber>
                    </xsl:if>
                    <xsl:if test="v20:failure/@messageSeverity">
                        <v10:messageSeverity>
                            <xsl:value-of 
                                 select="v20:failure/@messageSeverity"/>
                        </v10:messageSeverity>
                    </xsl:if>
                    <xsl:if test="v20:failure/@message">
                        <v10:message>
                            <xsl:value-of select="v20:failure/@message"/>
                        </v10:message>
                    </xsl:if>
                    <xsl:for-each select="v20:failure/v20:traceback">
                        <v10:traceback>
                            <xsl:if test="@programUnitName">
                                <v10:programUnitName>
                                    <xsl:value-of select="@programUnitName"/>
                                </v10:programUnitName>
                            </xsl:if>
                            <xsl:if test="@entryName">
                                <v10:entryName>
                                    <xsl:value-of select="@entryName"/>
                                </v10:entryName>
                            </xsl:if>
                            <xsl:if test="@statementID">
                                <v10:statementID>
                                    <xsl:value-of select="@statementID"/>
                                </v10:statementID>
                            </xsl:if>
                        </v10:traceback>
                    </xsl:for-each>
                </v10:exception>
            </xsl:if>
            <xsl:if test="v20:error">
                <v10:exception>
                    <xsl:if test="v20:error/@componentCode">
                        <v10:componentCode>
                            <xsl:value-of select="v20:error/@componentCode"/>
                        </v10:componentCode>
                    </xsl:if>
                    <xsl:if test="v20:error/@messageNumber">
                        <v10:messageNumber>
                            <xsl:value-of select="v20:error/@messageNumber"/>
                        </v10:messageNumber>
                    </xsl:if>
                    <xsl:if test="v20:error/@messageSeverity">
                        <v10:messageSeverity>
                            <xsl:value-of select="v20:error/@messageSeverity"/>
                        </v10:messageSeverity>
                    </xsl:if>
                    <xsl:if test="v20:error/@message">
                        <v10:message>
                            <xsl:value-of select="v20:error/@message"/>
                        </v10:message>
                    </xsl:if>
                    <xsl:for-each select="v20:error/v20:traceback">
                        <v10:traceback>
                            <xsl:if test="@programUnitName">
                                <v10:programUnitName>
                                    <xsl:value-of select="@programUnitName"/>
                                </v10:programUnitName>
                            </xsl:if>
                            <xsl:if test="@entryName">
                                <v10:entryName>
                                    <xsl:value-of select="@entryName"/>
                                </v10:entryName>
                            </xsl:if>
                            <xsl:if test="@statementID">
                                <v10:statementID>
                                    <xsl:value-of select="@statementID"/>
                                </v10:statementID>
                            </xsl:if>
                        </v10:traceback>
                    </xsl:for-each>
                </v10:exception>
            </xsl:if>
        </v10:testCase>
    </xsl:template>

    <xsl:template match="v20:test">
        <v10:test>
            <v10:name>
                <xsl:value-of select="@name"/>
            </v10:name>
            <v10:start>
                <xsl:value-of select="@startTimestamp"/>
            </v10:start>
            <v10:end>
                <xsl:value-of select="@endTimestamp"/>
            </v10:end>
            <v10:result>
                <xsl:value-of select="@result"/>
            </v10:result>
            <xsl:if test="v20:failure">
                <v10:exception>
                    <xsl:if test="v20:failure/@componentCode">
                        <v10:componentCode>
                            <xsl:value-of select="v20:failure/@componentCode"/>
                        </v10:componentCode>
                    </xsl:if>
                    <xsl:if test="v20:failure/@messageNumber">
                        <v10:messageNumber>
                            <xsl:value-of select="v20:failure/@messageNumber"/>
                        </v10:messageNumber>
                    </xsl:if>
                    <xsl:if test="v20:failure/@messageSeverity">
                        <v10:messageSeverity>
                            <xsl:value-of 
                                 select="v20:failure/@messageSeverity"/>
                        </v10:messageSeverity>
                    </xsl:if>
                    <xsl:if test="v20:failure/@message">
                        <v10:message>
                            <xsl:value-of select="v20:failure/@message"/>
                        </v10:message>
                    </xsl:if>
                    <xsl:for-each select="v20:failure/v20:traceback">
                        <v10:traceback>
                            <xsl:if test="@programUnitName">
                                <v10:programUnitName>
                                    <xsl:value-of select="@programUnitName"/>
                                </v10:programUnitName>
                            </xsl:if>
                            <xsl:if test="@entryName">
                                <v10:entryName>
                                    <xsl:value-of select="@entryName"/>
                                </v10:entryName>
                            </xsl:if>
                            <xsl:if test="@statementID">
                                <v10:statementID>
                                    <xsl:value-of select="@statementID"/>
                                </v10:statementID>
                            </xsl:if>
                        </v10:traceback>
                    </xsl:for-each>
                </v10:exception>
            </xsl:if>
            <xsl:if test="v20:error">
                <v10:exception>
                    <xsl:if test="v20:error/@componentCode">
                        <v10:componentCode>
                            <xsl:value-of select="v20:error/@componentCode"/>
                        </v10:componentCode>
                    </xsl:if>
                    <xsl:if test="v20:error/@messageNumber">
                        <v10:messageNumber>
                            <xsl:value-of select="v20:error/@messageNumber"/>
                        </v10:messageNumber>
                    </xsl:if>
                    <xsl:if test="v20:error/@messageSeverity">
                        <v10:messageSeverity>
                            <xsl:value-of select="v20:error/@messageSeverity"/>
                        </v10:messageSeverity>
                    </xsl:if>
                    <xsl:if test="v20:error/@message">
                        <v10:message>
                            <xsl:value-of select="v20:error/@message"/>
                        </v10:message>
                    </xsl:if>
                    <xsl:for-each select="v20:error/v20:traceback">
                        <v10:traceback>
                            <xsl:if test="@programUnitName">
                                <v10:programUnitName>
                                    <xsl:value-of select="@programUnitName"/>
                                </v10:programUnitName>
                            </xsl:if>
                            <xsl:if test="@entryName">
                                <v10:entryName>
                                    <xsl:value-of select="@entryName"/>
                                </v10:entryName>
                            </xsl:if>
                            <xsl:if test="@statementID">
                                <v10:statementID>
                                    <xsl:value-of select="@statementID"/>
                                </v10:statementID>
                            </xsl:if>
                        </v10:traceback>
                    </xsl:for-each>
                </v10:exception>
            </xsl:if>
        </v10:test>
    </xsl:template>

</xsl:stylesheet>
